IntoNullable

Trait IntoNullable 

pub trait IntoNullable {
    type Nullable;
}
Converts a type which may or may not be nullable into its nullable representation.

Required Associated Types

type Nullable

The nullable representation of this type.

For all types except Nullable, this will be Nullable<Self>.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> IntoNullable for Nullable<T>
where T: SqlType,

Source

impl<T> IntoNullable for T
where T: SqlType<IsNull = NotNull> + SingleValue,